<?php
if (!defined('_PS_VERSION_'))
        exit;

require_once __DIR__ . '/classes/TmbFeedParameters.php';
require_once __DIR__ . '/classes/TmbCvettaCatalogue.php';
require_once __DIR__ . '/classes/TmbCvettaFeed.php';

class ITTWebCvetta extends Module
{
        private static $_hooks;
        private static $_controllers = array();
        private static $_order_states = array();
        protected $db;

        // A true se la versione di Prestashop utilizzata è inferiore alla 1.6
        public $legacy_mode = false;

        public function __construct()
        {
                $this->name = 'ittwebcvetta';
                $this->tab = 'others';
                $this->version = '1.3.3';
                $this->author = 'Tembo Communication Design';
                $this->need_instance = 0;

                $this->bootstrap = true;

                parent::__construct();

                $this->displayName = $this->l('cVetta');
                $this->description = $this->l('cVetta Search');

                $this->ps_versions_compliancy = array('min' => '1.7','max'=>_PS_VERSION_);

                $this->id_shop_group = $this->context->shop->id_shop_group;
                $this->id_shop = $this->context->shop->id;
                $this->id_lang = (int)$this->context->language->id;

                $this->db = Db::getInstance();

                self::$_controllers = array(
                    array(
                        'page' => 'module-tmbcvetta-catalogue',
                        'title' => 'cVetta Catalogue',
                        'description' => 'cVetta Catalogue',
                        'url_rewrite' => 'cvetta-catalogue'
                    )
                );

                self::$_hooks = array('header', 'top', 'displayMobileTopSiteMap', 'displaySearch', 'topCvetta');

                if (Tools::version_compare(_PS_VERSION_, '1.6', '<'))
                        $this->legacy_mode = true;
        }

        public function install()
        {

                if (Module::isInstalled('blocksearch'))
                {
                        if ($this->legacy_mode)
                                Module::getInstanceByName('blocksearch')->disable();
                        else
                                Module::disableByName('blocksearch');
                }

                if (!parent::install())
                        return false;

                // Install hook
                if (!empty(self::$_hooks))
                {
                        foreach (self::$_hooks as $hook_name)
                                if (!$this->registerHook($hook_name))
                                        return false;
                }

                // Install config parameters
                if (!$this->installConfigParameters())
                        return false;

                // Install SQL
                // $install_sql = file_get_contents(__DIR__.'/sql/install.sql');
                // $install_sql = str_replace('{DB_PREFIX}', _DB_PREFIX_, $install_sql);
                // if (!$this->db->execute($install_sql))
                //	return false;
                // Install meta pages (for module front controller)
                if (!$this->installMeta())
                        return false;

                $position = 1;
                $way = 0; // bool $way Up (0) or Down (1)
                $id_hook = Hook::getIdByName('top');
                if (!$this->updatePosition($id_hook, $way, $position))
                        return false;

                $dynamic_css = $this->local_path . 'views/css/cvetta-dynamic.css';
                if (!file_exists($dynamic_css))
                        fopen($dynamic_css, 'w');

                return true;
        }

        public function installConfigParameters()
        {
                $res = true;

                $res &= Configuration::updateGlobalValue('TMBCVETTA_ACTIVE_SEARCH', 0);
                $res &= Configuration::updateGlobalValue('TMBCVETTA_FEED_SHOP', 1);
                $res &= Configuration::updateGlobalValue('TMBCVETTA_USERNAME', '');
                $res &= Configuration::updateGlobalValue('TMBCVETTA_PASSWORD', '');
                $res &= Configuration::updateGlobalValue('TMBCVETTA_ID_VETRINA', '');
    	    	foreach(Language::getLanguages(false) as $language){
    	    		$res &= Configuration::updateGlobalValue('TMBCVETTA_ID_VETRINA_'.$language['id_lang'], '');
    	    	}
                $res &= Configuration::updateGlobalValue('TMBCVETTA_FEED_LANG', 1);
                $res &= Configuration::updateGlobalValue('TMBCVETTA_FEED_PARAMS', '');
                $res &= Configuration::updateGlobalValue('TMBCVETTA_FEED_LIMIT', 1000);
                $res &= Configuration::updateGlobalValue('TMBCVETTA_SEARCH_BLOCK_CLASS', 'col-sm-4');
                $res &= Configuration::updateGlobalValue('TMBCVETTA_DEBUG_BASEURL', '');

                return $res;
        }

        public function installMeta()
        {
                $languages = Language::getLanguages(false);

                foreach (self::$_controllers as &$controller)
                {
                        $meta = new Meta();
                        $meta->page = $controller['page'];
                        foreach ($languages as $l)
                        {
                                $meta->title[$l['id_lang']] = $controller['title'];
                                $meta->description[$l['id_lang']] = $controller['description'];
                                $meta->url_rewrite[$l['id_lang']] = $controller['url_rewrite'];
                        }
                        if (!$meta->add())
                                return false;
                        unset($meta);
                }

                return true;
        }

        public function hookTopCvetta()
        {
                return $this->hookTop();
        }

        public function hookLeftColumn()
        {
            return $this->hookTop();
        }
        public function hookTop()
        {
                $active = (bool)Configuration::get('TMBCVETTA_ACTIVE_SEARCH');
                if (!$active)
                        return;

                $this->smarty->assign('search_block_class', (string)Configuration::get('TMBCVETTA_SEARCH_BLOCK_CLASS'));

                if (Tools::getValue('search_query'))
                {
                        $this->smarty->assign(array(
                                'blocksearch_type' => 'top',
                                'search_query' => (string)Tools::getValue('search_query')
                            )
                        );
                }

                if (!$this->legacy_mode)
                        return $this->display($this->name, 'form.tpl');
                else
                        return $this->display($this->name, 'form-15.tpl');
        }

        public function hookHeader()
        {
                $active = (bool)Configuration::get('TMBCVETTA_ACTIVE_SEARCH');
                if (!$active)
                        return;

                if ( ( isset($_SERVER['HTTPS']) && filter_var($_SERVER['HTTPS'], FILTER_VALIDATE_BOOLEAN) ) || 1)
                        $cvetta_domain = 'https://ws10b.cvetta.io';

                if (!$this->legacy_mode)
                {
                    $this->context->controller->addCSS($this->_path . 'views/css/cVetta_ext.css', 'all');
                    $this->context->controller->registerJavascript($this->name . '-cvetta-js', $cvetta_domain . '/js/cvetta.min.js', array('server' => 'remote'));
                }
                else
                {
                        $this->context->smarty->assign('cvetta_domain', $cvetta_domain);
                        return $this->display($this->name, 'header.tpl');
                }
                // Add Cvetta CSS and header
                if (!$this->legacy_mode)
                        $this->context->controller->addCSS($this->_path . 'views/css/cvetta.css', 'all');
                else
                        $this->context->controller->addCSS($this->_path . 'views/css/cvetta-15.css', 'all');

                $this->context->controller->addCSS($this->_path . 'views/css/cvetta-dynamic.css', 'all');

                $cvetta_domain = 'http://ws10b.cvetta.io:8454';
                // Forza HTTPS per accedere alla risorsa
                // (è capitato più volte che la risorsa http://ws10b.cvetta.io:8454 non rispondesse)

        }

        public function uninstall()
        {
                // Uninstall SQL
                // $uninstall_sql = file_get_contents(__DIR__.'/sql/uninstall.sql');
                // $uninstall_sql = str_replace('{DB_PREFIX}', _DB_PREFIX_, $uninstall_sql);
                // if (!$this->db->execute($uninstall_sql))
                // return false;
                // Delete Meta module front controller
                foreach (self::$_controllers as &$controller)
                {
                        $meta = Meta::getMetaByPage($controller['page'], $this->id_lang);
                        $meta_obj = new Meta($meta['id_meta']);
                        $meta_obj->delete();
                }

                // Delete order state
                foreach (self::$_order_states as &$os)
                {
                        $order_state = new OrderState((int)Configuration::get($os['key']));
                        if (!$order_state->delete())
                                return false;

                        if (!Configuration::deleteByName($os['key']))
                                return false;
                }

                // Uninstall config parameters
                if (!$this->unInstallConfigParameters())
                        return false;

                if (Module::isInstalled('blocksearch') && !Module::isEnabled('blocksearch'))
                {
                        if ($this->legacy_mode)
                                Module::getInstanceByName('blocksearch')->enable();
                        else
                                Module::enableByName('blocksearch');
                }

                if (!parent::uninstall())
                        return false;

                return true;
        }

        public function unInstallConfigParameters()
        {
                $res = true;
                $res &= Configuration::deleteByName('TMBCVETTA_ACTIVE_SEARCH');
                return $res;
        }

        public function getContent()
        {
                if (((bool)Tools::isSubmit('submitCvettaModule')) == true)
                        $this->postProcess();

                $this->context->controller->addJqueryUI(
                    array('ui.progressbar')
                );

                $base_url = Tools::getShopProtocol() . $this->context->shop->domain . $this->context->shop->physical_uri;

                $selected_cvetta_shop = Configuration::get('TMBCVETTA_FEED_SHOP');
                if (empty($selected_cvetta_shop))
                        $selected_cvetta_shop = array($this->context->shop->id);
                else
                        $selected_cvetta_shop = explode(',', $selected_cvetta_shop);

                $selected_cvetta_lang = Configuration::get('TMBCVETTA_FEED_LANG');
                if (empty($selected_cvetta_lang))
                        $selected_cvetta_lang = array($this->context->language->id);
                else
                        $selected_cvetta_lang = explode(',', $selected_cvetta_lang);

                $feed_data = array();

                foreach ($selected_cvetta_shop as $id_shop)
                {
                        $shop = new Shop($id_shop);
                        $feed_data[$id_shop]['name'] = $shop->name;

                        $feed = new TmbCvettaFeed($shop->id);

                        $feed_data[$id_shop]['catalogue'] = $feed->getIndexes();
                        $feed_data[$id_shop]['catalogue']['url'] = $base_url . 'modules/' . $this->name . '/feed/catalogue.php?id_shop=' . $id_shop . '&task=create';
                        foreach ($selected_cvetta_lang as $id_lang)
                                $feed_data[$id_shop]['feed'][$id_lang] = $base_url . 'modules/' . $this->name . '/feed/catalogue.php?id_shop=' . $id_shop . '&id_lang=' . $id_lang . '&task=feed';
                }

                //ddd($feed_data);

                $this->context->smarty->assign(array(
                    'feed_data' => $feed_data,
                    'base_cantroller_url' => $base_url . 'modules/' . $this->name . '/feed/catalogue.php',
                    'base_module_url' => $base_url . 'modules/' . $this->name . '/',
                    'selected_cvetta_shop' => $selected_cvetta_shop,
                ));

                $output = $this->context->smarty->fetch($this->local_path . 'views/templates/admin/configure.tpl');

                return $output . $this->renderForm();
        }

        /**
         * Save form data.
         */
        protected function postProcess()
        {

                if (Tools::getIsset('categoryBox') || Tools::getIsset('id_category'))
                {
                        if ($this->legacy_mode)
                                TmbFeedParameters::updateParam('id_category', json_encode(Tools::getValue('categoryBox'), JSON_NUMERIC_CHECK));
                        else
                                TmbFeedParameters::updateParam('id_category', json_encode(Tools::getValue('id_category'), JSON_NUMERIC_CHECK));
                }
                else
                        TmbFeedParameters::deleteParam('id_category');


                $cvetta_shop = $cvetta_lang = $cvetta_attributes_group = $cvetta_features = $cvetta_restrict_products = array();

                foreach ($_POST as $key => $value)
                {
                        if (strpos($key, 'cvetta_shop') !== false)
                                $cvetta_shop[] = $value;
                        elseif (strpos($key, 'cvetta_lang') !== false)
                                $cvetta_lang[] = $value;
                        elseif (strpos($key, 'cvetta_attributes_group') !== false)
                                $cvetta_attributes_group[] = $value;
                        elseif (strpos($key, 'cvetta_features') !== false)
                                $cvetta_features[] = $value;
                        elseif (strpos($key, 'cvetta_restrict_products') !== false)
                                $cvetta_restrict_products[] = $value;
                        elseif ($key == 'TMBCVETTA_CSS')
                                file_put_contents(__DIR__ . '/views/css/cvetta-dynamic.css', $value);
                }

                Configuration::updateGlobalValue('TMBCVETTA_FEED_SHOP', implode(',', $cvetta_shop));
                Configuration::updateGlobalValue('TMBCVETTA_FEED_LANG', implode(',', $cvetta_lang));


                if (!empty($cvetta_attributes_group))
                        TmbFeedParameters::updateParam('id_attributes_group', json_encode($cvetta_attributes_group, JSON_NUMERIC_CHECK));
                else
                        TmbFeedParameters::deleteParam('id_attributes_group');

                if (!empty($cvetta_features))
                        TmbFeedParameters::updateParam('id_features', json_encode($cvetta_features, JSON_NUMERIC_CHECK));
                else
                        TmbFeedParameters::deleteParam('id_features');

                if (!empty($cvetta_restrict_products))
                        TmbFeedParameters::updateParam('restrict_products', json_encode($cvetta_restrict_products, JSON_NUMERIC_CHECK));
                else
                        TmbFeedParameters::deleteParam('restrict_products');


                $form_values = $this->getConfigFormValues();

                foreach (array_keys($form_values) as $key)
                {
                        if (strpos($key, 'cvetta_shop') === false
                            && strpos($key, 'cvetta_lang') === false
                            && strpos($key, 'cvetta_attributes_group') === false
                            && strpos($key, 'cvetta_features') === false
                            && strpos($key, 'cvetta_restrict_products') === false
                        )
                        {

                                Configuration::updateGlobalValue($key, Tools::getValue($key));
                        }

                }

        }

        /**
         * Set values for the inputs.
         */
        protected function getConfigFormValues()
        {
                $selected_cvetta_shop = Configuration::get('TMBCVETTA_FEED_SHOP');
                if (strpos($selected_cvetta_shop, ',') !== false)
                        $selected_cvetta_shop = explode(',', $selected_cvetta_shop);
                else
                        $selected_cvetta_shop = array($selected_cvetta_shop);

                $selected_cvetta_lang = Configuration::get('TMBCVETTA_FEED_LANG');
                if (strpos($selected_cvetta_lang, ',') !== false)
                        $selected_cvetta_lang = explode(',', $selected_cvetta_lang);
                else
                        $selected_cvetta_lang = array($selected_cvetta_lang);

                $return = array(
                    'TMBCVETTA_ACTIVE_SEARCH' => (bool)Configuration::get('TMBCVETTA_ACTIVE_SEARCH'),
                    'TMBCVETTA_USERNAME' => Configuration::get('TMBCVETTA_USERNAME'),
                    'TMBCVETTA_PASSWORD' => Configuration::get('TMBCVETTA_PASSWORD'),
                    'TMBCVETTA_ID_VETRINA' => Configuration::get('TMBCVETTA_ID_VETRINA'),
                    'TMBCVETTA_FEED_LIMIT' => Configuration::get('TMBCVETTA_FEED_LIMIT'),
                    'TMBCVETTA_SEARCH_BLOCK_CLASS' => Configuration::get('TMBCVETTA_SEARCH_BLOCK_CLASS'),
                    'TMBCVETTA_CSS' => file_get_contents(__DIR__ . '/views/css/cvetta-dynamic.css')
                );
        		foreach(Language::getLanguages(false) as $language){
        			$return['TMBCVETTA_ID_VETRINA_'.$language['id_lang']] = Configuration::get('TMBCVETTA_ID_VETRINA_'.$language['id_lang']);
        		}
                if (!empty($selected_cvetta_shop))
                        foreach ($selected_cvetta_shop as $cvetta_shop)
                                $return['cvetta_shop_' . $cvetta_shop] = 1;

                if (!empty($selected_cvetta_lang))
                        foreach ($selected_cvetta_lang as $cvetta_lang)
                                $return['cvetta_lang_' . $cvetta_lang] = 1;

                $selected_attributes_group = array();
                if (!is_null(TmbFeedParameters::getParam('id_attributes_group')))
                        $selected_attributes_group = json_decode(TmbFeedParameters::getParam('id_attributes_group'), true);

                if (!empty($selected_attributes_group))
                        foreach ($selected_attributes_group as $id_attribute_group)
                                $return['cvetta_attributes_group_' . $id_attribute_group] = 1;

                $selected_features = array();
                if (!is_null(TmbFeedParameters::getParam('id_features')))
                        $selected_features = json_decode(TmbFeedParameters::getParam('id_features'), true);

                if (!empty($selected_features))
                        foreach ($selected_features as $id_features)
                                $return['cvetta_features_' . $id_features] = 1;

                $selected_restrict_products = array();
                if (!is_null(TmbFeedParameters::getParam('restrict_products')))
                        $selected_restrict_products = json_decode(TmbFeedParameters::getParam('restrict_products'), true);

                if (!empty($selected_restrict_products))
                        foreach ($selected_restrict_products as $restrict_products)
                                $return['cvetta_restrict_products_' . $restrict_products] = 1;

                return $return;
        }

        /**
         * Create the form that will be displayed in the configuration of your module.
         */
        protected function renderForm()
        {
                $this->identifier = 'id_feed';
                $this->table = 'tmbcvetta_feed';
                $this->id = 1;

                $helper = new HelperForm();

                $helper->show_toolbar = false;
                $helper->table = $this->table;
                $helper->module = $this;
                $helper->default_form_language = $this->context->language->id;
                $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

                $helper->identifier = $this->identifier;
                $helper->submit_action = 'submitCvettaModule';
                $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
                    . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;
                $helper->token = Tools::getAdminTokenLite('AdminModules');

                $helper->tpl_vars = array(
                    'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
                    'languages' => $this->context->controller->getLanguages(),
                    'id_language' => $this->context->language->id,
                );

                return $helper->generateForm(array($this->getConfigForm()));
        }

        /**
         * Create the structure of your form.
         */
        protected function getConfigForm()
        {

                $checkboxes_shops = $checkboxes_langs = $checkboxes_attributes_group = $checkboxes_features = $checkboxes_restrict_products = array();

                $shops = Shop::getShops();

                foreach ($shops as $key => $shop)
                {
                        $checkboxes_shops[$key]['id'] = $shop['id_shop'];
                        $checkboxes_shops[$key]['name'] = $shop['name']; // . ' (' . $shop['id_shop'] . ')';
                        $checkboxes_shops[$key]['val'] = $shop['id_shop'];
                }

                $languages = Language::getLanguages(false);

                foreach ($languages as $key => $lang)
                {
                        $checkboxes_langs[$key]['id'] = $lang['id_lang'];
                        $checkboxes_langs[$key]['name'] = $lang['name']; // . ' (' . $lang['id_lang'] . ')';
                        $checkboxes_langs[$key]['val'] = $lang['id_lang'];
                }

                $selected_categories = array();
                if (!is_null(TmbFeedParameters::getParam('id_category')))
                        $selected_categories = json_decode(TmbFeedParameters::getParam('id_category'), true);

                $attributes_group = AttributeGroup::getAttributesGroups($this->context->language->id);

                foreach ($attributes_group as $key => $group)
                {
                        $checkboxes_attributes_group[$key]['id'] = $group['id_attribute_group'];
                        $checkboxes_attributes_group[$key]['name'] = $group['name']; //. ' (' . $group['id_attribute_group'] . ' - ' . $group['public_name'] . ')';
                        $checkboxes_attributes_group[$key]['val'] = $group['id_attribute_group'];
                }

                $features = Feature::getFeatures($this->context->language->id, true);

                foreach ($features as $key => $feature)
                {
                        $feature_values = FeatureValue::getFeatureValues($feature['id_feature']);

                        if (empty($feature_values))
                                continue;

                        $checkboxes_features[$key]['id'] = $feature['id_feature'];
                        $checkboxes_features[$key]['name'] = $feature['name']; // . ' (' . $feature['id_feature'] . ')';
                        $checkboxes_features[$key]['val'] = $feature['id_feature'];
                }

                $checkboxes_restrict_products[0]['id'] = 1;
                $checkboxes_restrict_products[0]['name'] = $this->l('Only active products');
                $checkboxes_restrict_products[0]['val'] = 1;

                $checkboxes_restrict_products[1]['id'] = 2;
                $checkboxes_restrict_products[1]['name'] = $this->l('Only products in stock');
                $checkboxes_restrict_products[1]['val'] = 2;

                $checkboxes_restrict_products[2]['id'] = 3;
                $checkboxes_restrict_products[2]['name'] = $this->l('Only products with image');
                $checkboxes_restrict_products[2]['val'] = 3;

                if ($this->legacy_mode)
                {
                        $tab_root = array('id_category' => 2, 'name' => 'Home page');
                        $helper = new Helper();
                        $category_tree = $helper->renderCategoryTree($tab_root, $selected_categories, 'categoryBox', false, true, array(), false, true);
                }

                $result =  array(
                    'form' => array(
                        'legend' => array(
                            'title' => $this->l('Settings'),
                            'icon' => 'icon-cogs',
                        ),
                        'input' => array(
                            array(
                                'type' => ($this->legacy_mode ? 'radio' : 'switch'),
                                'label' => $this->l('cVetta search'),
                                'name' => 'TMBCVETTA_ACTIVE_SEARCH',
                                'class' => 't',
                                'is_bool' => true,
                                'desc' => $this->l('Active cVetta search'),
                                'values' => array(
                                    array(
                                        'id' => 'active_on',
                                        'value' => true,
                                        'label' => $this->l('Enabled')
                                    ),
                                    array(
                                        'id' => 'active_off',
                                        'value' => false,
                                        'label' => $this->l('Disabled')
                                    )
                                ),
                            ),
                            array(
                                'type' => 'text',
                                'label' => $this->l('FTP Username'),
                                'name' => 'TMBCVETTA_USERNAME',
                                'class' => 'fixed-width-xxl', // xs, sm, md, lg, xl, or xxl.
                                'desc' => $this->l('Username for FTP connection')
                            ),
                            array(
                                'type' => 'text',
                                'label' => $this->l('FTP Password'),
                                'name' => 'TMBCVETTA_PASSWORD',
                                'class' => 'fixed-width-xxl',
                                'desc' => $this->l('Password for FTP connection')
                            ),
                        ),
                        'submit' => array(
                            'name' => 'submitCvettaModule',
                            'title' => $this->l('Save'),
                        ),
                    )
                );
                $languages = LanguageCore::getLanguages(false);
                $label = $this->l('ID Vetrine');
                foreach($languages as $language){
                	$result['form']['input'][] =
                            array(
                                'type' => 'text',
                                'label' => $label,
                                'name' => 'TMBCVETTA_ID_VETRINA_'.$language['id_lang'],
                                'class' => 'fixed-width-xxl',
                                'desc' => $language['name']
                            );
                    $label = '';
                }
                $result['form']['input'][] =
                            array(
                                'type' => 'checkbox',
                                'label' => $this->l('Feed per shop'),
                                'desc' => $this->l('Activated feed per shop.'),
                                'name' => 'cvetta_shop',
                                'values' => array(
                                    'query' => $checkboxes_shops,
                                    'id' => 'id',
                                    'name' => 'name'
                                ),
                            );
                $result['form']['input'][] =
                            array(
                                'type' => 'checkbox',
                                'label' => $this->l('Feed per language'),
                                'desc' => $this->l('Activated feed per language.'),
                                'name' => 'cvetta_lang',
                                'values' => array(
                                    'query' => $checkboxes_langs,
                                    'id' => 'id',
                                    'name' => 'name'
                                ),
                            );
                $result['form']['input'][] =
                            array(
                                'type' => 'checkbox',
                                'label' => $this->l('Insert attributes'),
                                'desc' => $this->l('Insert attributes.'),
                                'name' => 'cvetta_attributes_group',
                                'values' => array(
                                    'query' => $checkboxes_attributes_group,
                                    'id' => 'id',
                                    'name' => 'name'
                                ),
                            );
                $result['form']['input'][] =
                            array(
                                'type' => 'checkbox',
                                'label' => $this->l('Insert features'),
                                'desc' => $this->l('Insert features.'),
                                'name' => 'cvetta_features',
                                'values' => array(
                                    'query' => $checkboxes_features,
                                    'id' => 'id',
                                    'name' => 'name'
                                ),
                            );
                $result['form']['input'][] =
                            array(
                                'type' => 'checkbox',
                                'label' => $this->l('Restrict feed to'),
                                'desc' => $this->l('Restrict feed to this products.'),
                                'name' => 'cvetta_restrict_products',
                                'values' => array(
                                    'query' => $checkboxes_restrict_products,
                                    'id' => 'id',
                                    'name' => 'name'
                                ),
                            );
                $result['form']['input'][] =
                            ($this->legacy_mode
                                ? array(
                                    'type' => 'categories_select',
                                    'label' => $this->l('Categorie'),
                                    'name' => 'id_category',
                                    'category_tree' => $category_tree
                                ) : array(
                                    'type' => 'categories',
                                    'label' => $this->l('Insert categories'),
                                    'name' => 'id_category',
                                    'tree' => array(
                                        'id' => 'id_root_category',
                                        'use_search' => true,
                                        'use_checkbox' => true,
                                        'selected_categories' => $selected_categories
                                    ),
                                    'desc' => $this->l('If you do not select any category, the resulting feed will include all product of your catalog. If you select some categories the resulting feed will include all products of seleted categories.')
                                ));
                $result['form']['input'][] =
                            array(
                                'type' => 'text',
                                'label' => $this->l('Feed limit'),
                                'name' => 'TMBCVETTA_FEED_LIMIT',
                                'class' => 'fixed-width-xxl', // xs, sm, md, lg, xl, or xxl.
                                'desc' => $this->l('Feed limit')
                            );
                $result['form']['input'][] =
                            array(
                                'type' => 'text',
                                'label' => $this->l('Search block class'),
                                'name' => 'TMBCVETTA_SEARCH_BLOCK_CLASS',
                                'class' => 'fixed-width-xxl', // xs, sm, md, lg, xl, or xxl.
                                'desc' => $this->l('Input the div search_block bootstrap class (default is "col-sm-4")')
                            );
                $result['form']['input'][] =
                            array(
                                'type' => 'textarea',
                                'label' => $this->l('CSS'),
                                'name' => 'TMBCVETTA_CSS',
                                'rows' => '10',
                                'desc' => $this->l('Customize the cVetta search box using your CSS style.')
                            );
            	return $result;
        }


}

